Class: Google::Apis::MonitoringV1::ColumnSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

The persistent settings for a table's columns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ColumnSettings

Returns a new instance of ColumnSettings.



371
372
373
# File 'lib/google/apis/monitoring_v1/classes.rb', line 371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alignmentString

Optional. Whether the column should be left / middle / right aligned Corresponds to the JSON property alignment

Returns:

  • (String)


347
348
349
# File 'lib/google/apis/monitoring_v1/classes.rb', line 347

def alignment
  @alignment
end

#columnString

Required. The id of the column. Corresponds to the JSON property column

Returns:

  • (String)


352
353
354
# File 'lib/google/apis/monitoring_v1/classes.rb', line 352

def column
  @column
end

#display_nameString

Optional. Display name of the column Corresponds to the JSON property displayName

Returns:

  • (String)


357
358
359
# File 'lib/google/apis/monitoring_v1/classes.rb', line 357

def display_name
  @display_name
end

#thresholdsArray<Google::Apis::MonitoringV1::Threshold>

Optional. The thresholds used to determine how the table cell should be rendered given the time series' current value. Corresponds to the JSON property thresholds



363
364
365
# File 'lib/google/apis/monitoring_v1/classes.rb', line 363

def thresholds
  @thresholds
end

#visibleBoolean Also known as: visible?

Required. Whether the column should be visible on page load. Corresponds to the JSON property visible

Returns:

  • (Boolean)


368
369
370
# File 'lib/google/apis/monitoring_v1/classes.rb', line 368

def visible
  @visible
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



376
377
378
379
380
381
382
# File 'lib/google/apis/monitoring_v1/classes.rb', line 376

def update!(**args)
  @alignment = args[:alignment] if args.key?(:alignment)
  @column = args[:column] if args.key?(:column)
  @display_name = args[:display_name] if args.key?(:display_name)
  @thresholds = args[:thresholds] if args.key?(:thresholds)
  @visible = args[:visible] if args.key?(:visible)
end