Class: Google::Apis::MonitoringV1::ColumnSortingOptions
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::ColumnSortingOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
Data structure to storing column's sort strategy
Instance Attribute Summary collapse
-
#column ⇒ String
Optional.
-
#direction ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ColumnSortingOptions
constructor
A new instance of ColumnSortingOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ColumnSortingOptions
Returns a new instance of ColumnSortingOptions.
400 401 402 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ String
Optional. Column name to sort data by
Corresponds to the JSON property column
392 393 394 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 392 def column @column end |
#direction ⇒ String
Optional. A sorting direction that determines ascending or descending order.
This is a legacy field kept for backwards compatibility with table.
Corresponds to the JSON property direction
398 399 400 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 398 def direction @direction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
405 406 407 408 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 405 def update!(**args) @column = args[:column] if args.key?(:column) @direction = args[:direction] if args.key?(:direction) end |