Class: Google::Apis::MonitoringV1::CoordinatedWidget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A widget that contains two widget visualizations that are coordinated in display. Currently, we only support the primary widget of TimeSeriesTable with the secondary widget of XyChart.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CoordinatedWidget

Returns a new instance of CoordinatedWidget.



429
430
431
# File 'lib/google/apis/monitoring_v1/classes.rb', line 429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#primaryGoogle::Apis::MonitoringV1::Widget

Widget contains a single dashboard component and configuration of how to present the component in the dashboard. Corresponds to the JSON property primary



421
422
423
# File 'lib/google/apis/monitoring_v1/classes.rb', line 421

def primary
  @primary
end

#secondaryGoogle::Apis::MonitoringV1::Widget

Widget contains a single dashboard component and configuration of how to present the component in the dashboard. Corresponds to the JSON property secondary



427
428
429
# File 'lib/google/apis/monitoring_v1/classes.rb', line 427

def secondary
  @secondary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



434
435
436
437
# File 'lib/google/apis/monitoring_v1/classes.rb', line 434

def update!(**args)
  @primary = args[:primary] if args.key?(:primary)
  @secondary = args[:secondary] if args.key?(:secondary)
end