Class: Google::Apis::MonitoringV1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A single field of a message type.New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



960
961
962
# File 'lib/google/apis/monitoring_v1/classes.rb', line 960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


910
911
912
# File 'lib/google/apis/monitoring_v1/classes.rb', line 910

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


915
916
917
# File 'lib/google/apis/monitoring_v1/classes.rb', line 915

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


920
921
922
# File 'lib/google/apis/monitoring_v1/classes.rb', line 920

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


925
926
927
# File 'lib/google/apis/monitoring_v1/classes.rb', line 925

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


930
931
932
# File 'lib/google/apis/monitoring_v1/classes.rb', line 930

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


935
936
937
# File 'lib/google/apis/monitoring_v1/classes.rb', line 935

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


941
942
943
# File 'lib/google/apis/monitoring_v1/classes.rb', line 941

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::MonitoringV1::Option>

The protocol buffer options. Corresponds to the JSON property options



946
947
948
# File 'lib/google/apis/monitoring_v1/classes.rb', line 946

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


951
952
953
# File 'lib/google/apis/monitoring_v1/classes.rb', line 951

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/monitoring_v1/classes.rb', line 958

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



965
966
967
968
969
970
971
972
973
974
975
976
# File 'lib/google/apis/monitoring_v1/classes.rb', line 965

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end