Class: Google::Apis::MonitoringV1::GaugeView
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::GaugeView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A gauge chart shows where the current value sits within a pre-defined range. The upper and lower bounds should define the possible range of values for the scorecard's query (inclusive).
Instance Attribute Summary collapse
-
#lower_bound ⇒ Float
The lower bound for this gauge chart.
-
#upper_bound ⇒ Float
The upper bound for this gauge chart.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GaugeView
constructor
A new instance of GaugeView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GaugeView
Returns a new instance of GaugeView.
1005 1006 1007 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lower_bound ⇒ Float
The lower bound for this gauge chart. The value of the chart should always be
greater than or equal to this.
Corresponds to the JSON property lowerBound
997 998 999 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 997 def lower_bound @lower_bound end |
#upper_bound ⇒ Float
The upper bound for this gauge chart. The value of the chart should always be
less than or equal to this.
Corresponds to the JSON property upperBound
1003 1004 1005 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1003 def upper_bound @upper_bound end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1010 1011 1012 1013 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1010 def update!(**args) @lower_bound = args[:lower_bound] if args.key?(:lower_bound) @upper_bound = args[:upper_bound] if args.key?(:upper_bound) end |