Class: Google::Apis::MonitoringV1::IncidentList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A widget that displays a list of incidents

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IncidentList

Returns a new instance of IncidentList.



1122
1123
1124
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#monitored_resourcesArray<Google::Apis::MonitoringV1::MonitoredResource>

Optional. The monitored resource for which incidents are listed. The resource doesn't need to be fully specified. That is, you can specify the resource type but not the values of the resource labels. The resource type and labels are used for filtering. Corresponds to the JSON property monitoredResources



1113
1114
1115
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1113

def monitored_resources
  @monitored_resources
end

#policy_namesArray<String>

Optional. A list of alert policy names to filter the incident list by. Don't include the project ID prefix in the policy name. For example, use alertPolicies/utilization. Corresponds to the JSON property policyNames

Returns:

  • (Array<String>)


1120
1121
1122
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1120

def policy_names
  @policy_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1127
1128
1129
1130
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1127

def update!(**args)
  @monitored_resources = args[:monitored_resources] if args.key?(:monitored_resources)
  @policy_names = args[:policy_names] if args.key?(:policy_names)
end