Class: Google::Apis::MonitoringV1::ListMetricsScopesByMonitoredProjectResponse
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::ListMetricsScopesByMonitoredProjectResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
Response for the ListMetricsScopesByMonitoredProject method.
Instance Attribute Summary collapse
-
#metrics_scopes ⇒ Array<Google::Apis::MonitoringV1::MetricsScope>
A set of all metrics scopes that the specified monitored project has been added to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMetricsScopesByMonitoredProjectResponse
constructor
A new instance of ListMetricsScopesByMonitoredProjectResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMetricsScopesByMonitoredProjectResponse
Returns a new instance of ListMetricsScopesByMonitoredProjectResponse.
1188 1189 1190 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1188 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metrics_scopes ⇒ Array<Google::Apis::MonitoringV1::MetricsScope>
A set of all metrics scopes that the specified monitored project has been
added to.
Corresponds to the JSON property metricsScopes
1186 1187 1188 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1186 def metrics_scopes @metrics_scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1193 1194 1195 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1193 def update!(**args) @metrics_scopes = args[:metrics_scopes] if args.key?(:metrics_scopes) end |