Class: Google::Apis::MonitoringV1::LogsPanel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A widget that displays a stream of log.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogsPanel

Returns a new instance of LogsPanel.



1228
1229
1230
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

A filter that chooses which log entries to return. See Advanced Logs Queries ( https://cloud.google.com/logging/docs/view/advanced-queries). Only log entries that match the filter are returned. An empty filter matches all log entries. Corresponds to the JSON property filter

Returns:

  • (String)


1219
1220
1221
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1219

def filter
  @filter
end

#resource_namesArray<String>

The names of logging resources to collect logs for. Currently projects and storage views are supported. If empty, the widget will default to the host project. Corresponds to the JSON property resourceNames

Returns:

  • (Array<String>)


1226
1227
1228
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1226

def resource_names
  @resource_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1233
1234
1235
1236
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1233

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @resource_names = args[:resource_names] if args.key?(:resource_names)
end