Class: Google::Apis::MonitoringV1::Measure
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::Measure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A chart measure. Measures represent a measured property in your chart data such as rainfall in inches, number of units sold, revenue gained, etc.
Instance Attribute Summary collapse
-
#aggregation_function ⇒ Google::Apis::MonitoringV1::AggregationFunction
Preview: An identifier for an aggregation function.
-
#column ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Measure
constructor
A new instance of Measure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Measure
Returns a new instance of Measure.
1271 1272 1273 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_function ⇒ Google::Apis::MonitoringV1::AggregationFunction
Preview: An identifier for an aggregation function. Aggregation functions are
SQL functions that group or transform data from multiple points to a single
point. This is a preview feature and may be subject to change before final
release.
Corresponds to the JSON property aggregationFunction
1264 1265 1266 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1264 def aggregation_function @aggregation_function end |
#column ⇒ String
Required. The column name within in the dataset used for the measure.
Corresponds to the JSON property column
1269 1270 1271 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1269 def column @column end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1276 1277 1278 1279 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1276 def update!(**args) @aggregation_function = args[:aggregation_function] if args.key?(:aggregation_function) @column = args[:column] if args.key?(:column) end |