Class: Google::Apis::MonitoringV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

Contains metadata for longrunning operation for the edit Metrics Scope endpoints.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1497
1498
1499
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time when the batch request was received. Corresponds to the JSON property createTime

Returns:

  • (String)


1485
1486
1487
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1485

def create_time
  @create_time
end

#stateString

Current state of the batch operation. Corresponds to the JSON property state

Returns:

  • (String)


1490
1491
1492
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1490

def state
  @state
end

#update_timeString

The time when the operation result was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1495
1496
1497
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1495

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1502
1503
1504
1505
1506
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1502

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end