Class: Google::Apis::MonitoringV1::PieChart
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::PieChart
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A widget that displays timeseries data as a pie or a donut.
Instance Attribute Summary collapse
-
#chart_type ⇒ String
Required.
-
#data_sets ⇒ Array<Google::Apis::MonitoringV1::PieChartDataSet>
Required.
-
#show_labels ⇒ Boolean
(also: #show_labels?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PieChart
constructor
A new instance of PieChart.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PieChart
Returns a new instance of PieChart.
1655 1656 1657 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart_type ⇒ String
Required. Indicates the visualization type for the PieChart.
Corresponds to the JSON property chartType
1642 1643 1644 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1642 def chart_type @chart_type end |
#data_sets ⇒ Array<Google::Apis::MonitoringV1::PieChartDataSet>
Required. The queries for the chart's data.
Corresponds to the JSON property dataSets
1647 1648 1649 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1647 def data_sets @data_sets end |
#show_labels ⇒ Boolean Also known as: show_labels?
Optional. Indicates whether or not the pie chart should show slices' labels
Corresponds to the JSON property showLabels
1652 1653 1654 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1652 def show_labels @show_labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1660 1661 1662 1663 1664 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1660 def update!(**args) @chart_type = args[:chart_type] if args.key?(:chart_type) @data_sets = args[:data_sets] if args.key?(:data_sets) @show_labels = args[:show_labels] if args.key?(:show_labels) end |