Class: Google::Apis::MonitoringV1::PieChartDataSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

Groups a time series query definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PieChartDataSet

Returns a new instance of PieChartDataSet.



1720
1721
1722
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<Google::Apis::MonitoringV1::Dimension>

A dimension is a structured label, class, or category for a set of measurements in your data. Corresponds to the JSON property dimensions



1689
1690
1691
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1689

def dimensions
  @dimensions
end

#measuresArray<Google::Apis::MonitoringV1::Measure>

A measure is a measured value of a property in your data. For example, rainfall in inches, number of units sold, revenue gained, etc. Corresponds to the JSON property measures



1695
1696
1697
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1695

def measures
  @measures
end

#min_alignment_periodString

Optional. The lower bound on data point frequency for this data set, implemented by specifying the minimum alignment period to use in a time series query. For example, if the data is published once every 10 minutes, the min_alignment_period should be at least 10 minutes. It would not make sense to fetch and align data at one minute intervals. Corresponds to the JSON property minAlignmentPeriod

Returns:

  • (String)


1704
1705
1706
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1704

def min_alignment_period
  @min_alignment_period
end

#slice_name_templateString

Optional. A template for the name of the slice. This name will be displayed in the legend and the tooltip of the pie chart. It replaces the auto-generated names for the slices. For example, if the template is set to $resource.labels. zone, the zone's value will be used for the name instead of the default name. Corresponds to the JSON property sliceNameTemplate

Returns:

  • (String)


1712
1713
1714
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1712

def slice_name_template
  @slice_name_template
end

#time_series_queryGoogle::Apis::MonitoringV1::TimeSeriesQuery

TimeSeriesQuery collects the set of supported methods for querying time series data from the Stackdriver metrics API. Corresponds to the JSON property timeSeriesQuery



1718
1719
1720
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1718

def time_series_query
  @time_series_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1725
1726
1727
1728
1729
1730
1731
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1725

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @measures = args[:measures] if args.key?(:measures)
  @min_alignment_period = args[:min_alignment_period] if args.key?(:min_alignment_period)
  @slice_name_template = args[:slice_name_template] if args.key?(:slice_name_template)
  @time_series_query = args[:time_series_query] if args.key?(:time_series_query)
end