Class: Google::Apis::MonitoringV1::QueryLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

QueryLabelsRequest holds all parameters of the Prometheus upstream API for returning a list of label names.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryLabelsRequest

Returns a new instance of QueryLabelsRequest.



1830
1831
1832
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1830

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endString

The end time to evaluate the query for. Either floating point UNIX seconds or RFC3339 formatted timestamp. Corresponds to the JSON property end

Returns:

  • (String)


1816
1817
1818
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1816

def end
  @end
end

#matchString

A list of matchers encoded in the Prometheus label matcher format to constrain the values to series that satisfy them. Corresponds to the JSON property match

Returns:

  • (String)


1822
1823
1824
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1822

def match
  @match
end

#startString

The start time to evaluate the query for. Either floating point UNIX seconds or RFC3339 formatted timestamp. Corresponds to the JSON property start

Returns:

  • (String)


1828
1829
1830
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1828

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1835
1836
1837
1838
1839
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1835

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @match = args[:match] if args.key?(:match)
  @start = args[:start] if args.key?(:start)
end