Class: Google::Apis::MonitoringV1::QueryRangeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

QueryRangeRequest holds all parameters of the Prometheus upstream range query API plus GCM specific parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryRangeRequest

Returns a new instance of QueryRangeRequest.



1857
1858
1859
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endString

The end time to evaluate the query for. Either floating point UNIX seconds or RFC3339 formatted timestamp. Corresponds to the JSON property end

Returns:

  • (String)


1825
1826
1827
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1825

def end
  @end
end

#queryString

A PromQL query string. Query language documentation: https://prometheus.io/ docs/prometheus/latest/querying/basics/. Corresponds to the JSON property query

Returns:

  • (String)


1831
1832
1833
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1831

def query
  @query
end

#startString

The start time to evaluate the query for. Either floating point UNIX seconds or RFC3339 formatted timestamp. Corresponds to the JSON property start

Returns:

  • (String)


1837
1838
1839
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1837

def start
  @start
end

#stepString

The resolution of query result. Either a Prometheus duration string (https:// prometheus.io/docs/prometheus/latest/querying/basics/#time-durations) or floating point seconds. This non-standard encoding must be used for compatibility with the open source API. Clients may still implement timeouts at the connection level while ignoring this field. Corresponds to the JSON property step

Returns:

  • (String)


1846
1847
1848
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1846

def step
  @step
end

#timeoutString

An upper bound timeout for the query. Either a Prometheus duration string ( https://prometheus.io/docs/prometheus/latest/querying/basics/#time-durations) or floating point seconds. This non-standard encoding must be used for compatibility with the open source API. Clients may still implement timeouts at the connection level while ignoring this field. Corresponds to the JSON property timeout

Returns:

  • (String)


1855
1856
1857
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1855

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1862
1863
1864
1865
1866
1867
1868
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1862

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @query = args[:query] if args.key?(:query)
  @start = args[:start] if args.key?(:start)
  @step = args[:step] if args.key?(:step)
  @timeout = args[:timeout] if args.key?(:timeout)
end