Class: Google::Apis::MonitoringV1::Row

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

Defines the layout properties and content for a row.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Row

Returns a new instance of Row.



1975
1976
1977
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#weightFixnum

The relative weight of this row. The row weight is used to adjust the height of rows on the screen (relative to peers). Greater the weight, greater the height of the row on the screen. If omitted, a value of 1 is used while rendering. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


1968
1969
1970
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1968

def weight
  @weight
end

#widgetsArray<Google::Apis::MonitoringV1::Widget>

The display widgets arranged horizontally in this row. Corresponds to the JSON property widgets



1973
1974
1975
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1973

def widgets
  @widgets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1980
1981
1982
1983
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1980

def update!(**args)
  @weight = args[:weight] if args.key?(:weight)
  @widgets = args[:widgets] if args.key?(:widgets)
end