Class: Google::Apis::MonitoringV1::SectionHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A widget that defines a new section header. Sections populate a table of contents and allow easier navigation of long-form content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SectionHeader

Returns a new instance of SectionHeader.



2110
2111
2112
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#divider_belowBoolean Also known as: divider_below?

Whether to insert a divider below the section in the table of contents Corresponds to the JSON property dividerBelow

Returns:

  • (Boolean)


2102
2103
2104
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2102

def divider_below
  @divider_below
end

#subtitleString

The subtitle of the section Corresponds to the JSON property subtitle

Returns:

  • (String)


2108
2109
2110
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2108

def subtitle
  @subtitle
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2115
2116
2117
2118
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2115

def update!(**args)
  @divider_below = args[:divider_below] if args.key?(:divider_below)
  @subtitle = args[:subtitle] if args.key?(:subtitle)
end