Class: Google::Apis::MonitoringV1::SingleViewGroup
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::SingleViewGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A widget that groups the other widgets by using a dropdown menu. All widgets that are within the area spanned by the grouping widget are considered member widgets.
Instance Attribute Summary collapse
-
#display_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleViewGroup
constructor
A new instance of SingleViewGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleViewGroup
Returns a new instance of SingleViewGroup.
2132 2133 2134 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_type ⇒ String
Optional. Determines how the widget selector will be displayed.
Corresponds to the JSON property displayType
2130 2131 2132 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2130 def display_type @display_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2137 2138 2139 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2137 def update!(**args) @display_type = args[:display_type] if args.key?(:display_type) end |