Class: Google::Apis::MonitoringV1::TemplateVariableCondition
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::TemplateVariableCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A condition whose evaluation is based on the value of a template variable.
Instance Attribute Summary collapse
-
#comparator ⇒ String
Comparator to use to evaluate whether the value of the template variable matches the template_variable_value.
-
#template_variable ⇒ String
The template variable whose value is evaluated.
-
#template_variable_value ⇒ String
The value to compare the template variable to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TemplateVariableCondition
constructor
A new instance of TemplateVariableCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TemplateVariableCondition
Returns a new instance of TemplateVariableCondition.
2397 2398 2399 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comparator ⇒ String
Comparator to use to evaluate whether the value of the template variable
matches the template_variable_value. For example, if the comparator is
REGEX_FULL_MATCH, template_variable_value would contain a regex that is
matched against the value of the template variable.
Corresponds to the JSON property comparator
2384 2385 2386 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2384 def comparator @comparator end |
#template_variable ⇒ String
The template variable whose value is evaluated.
Corresponds to the JSON property templateVariable
2389 2390 2391 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2389 def template_variable @template_variable end |
#template_variable_value ⇒ String
The value to compare the template variable to. For example, if the comparator
is REGEX_FULL_MATCH, this field should contain a regex.
Corresponds to the JSON property templateVariableValue
2395 2396 2397 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2395 def template_variable_value @template_variable_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2402 2403 2404 2405 2406 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2402 def update!(**args) @comparator = args[:comparator] if args.key?(:comparator) @template_variable = args[:template_variable] if args.key?(:template_variable) @template_variable_value = args[:template_variable_value] if args.key?(:template_variable_value) end |