Class: Google::Apis::MonitoringV1::Text
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::Text
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A widget that displays textual content.
Instance Attribute Summary collapse
-
#content ⇒ String
The text content to be displayed.
-
#format ⇒ String
How the text content is formatted.
-
#style ⇒ Google::Apis::MonitoringV1::TextStyle
Properties that determine how the title and content are styled Corresponds to the JSON property
style.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Text
constructor
A new instance of Text.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Text
Returns a new instance of Text.
2439 2440 2441 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
The text content to be displayed.
Corresponds to the JSON property content
2427 2428 2429 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2427 def content @content end |
#format ⇒ String
How the text content is formatted.
Corresponds to the JSON property format
2432 2433 2434 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2432 def format @format end |
#style ⇒ Google::Apis::MonitoringV1::TextStyle
Properties that determine how the title and content are styled
Corresponds to the JSON property style
2437 2438 2439 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2437 def style @style end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2444 2445 2446 2447 2448 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2444 def update!(**args) @content = args[:content] if args.key?(:content) @format = args[:format] if args.key?(:format) @style = args[:style] if args.key?(:style) end |