Class: Google::Apis::MonitoringV1::TextStyle

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

Properties that determine how the title and content are styled

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TextStyle

Returns a new instance of TextStyle.



2491
2492
2493
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_colorString

The background color as a hex string. "#RRGGBB" or "#RGB" Corresponds to the JSON property backgroundColor

Returns:

  • (String)


2458
2459
2460
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2458

def background_color
  @background_color
end

#font_sizeString

Font sizes for both the title and content. The title will still be larger relative to the content. Corresponds to the JSON property fontSize

Returns:

  • (String)


2464
2465
2466
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2464

def font_size
  @font_size
end

#horizontal_alignmentString

The horizontal alignment of both the title and content Corresponds to the JSON property horizontalAlignment

Returns:

  • (String)


2469
2470
2471
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2469

def horizontal_alignment
  @horizontal_alignment
end

#paddingString

The amount of padding around the widget Corresponds to the JSON property padding

Returns:

  • (String)


2474
2475
2476
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2474

def padding
  @padding
end

#pointer_locationString

The pointer location for this widget (also sometimes called a "tail") Corresponds to the JSON property pointerLocation

Returns:

  • (String)


2479
2480
2481
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2479

def pointer_location
  @pointer_location
end

#text_colorString

The text color as a hex string. "#RRGGBB" or "#RGB" Corresponds to the JSON property textColor

Returns:

  • (String)


2484
2485
2486
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2484

def text_color
  @text_color
end

#vertical_alignmentString

The vertical alignment of both the title and content Corresponds to the JSON property verticalAlignment

Returns:

  • (String)


2489
2490
2491
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2489

def vertical_alignment
  @vertical_alignment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2496
2497
2498
2499
2500
2501
2502
2503
2504
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2496

def update!(**args)
  @background_color = args[:background_color] if args.key?(:background_color)
  @font_size = args[:font_size] if args.key?(:font_size)
  @horizontal_alignment = args[:horizontal_alignment] if args.key?(:horizontal_alignment)
  @padding = args[:padding] if args.key?(:padding)
  @pointer_location = args[:pointer_location] if args.key?(:pointer_location)
  @text_color = args[:text_color] if args.key?(:text_color)
  @vertical_alignment = args[:vertical_alignment] if args.key?(:vertical_alignment)
end