Class: Google::Apis::MonitoringV1::TimeSeriesQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

TimeSeriesQuery collects the set of supported methods for querying time series data from the Stackdriver metrics API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeSeriesQuery

Returns a new instance of TimeSeriesQuery.



2798
2799
2800
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ops_analytics_queryGoogle::Apis::MonitoringV1::OpsAnalyticsQuery

Preview: A query that produces an aggregated response and supporting data. This is a preview feature and may be subject to change before final release. Corresponds to the JSON property opsAnalyticsQuery



2755
2756
2757
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2755

def ops_analytics_query
  @ops_analytics_query
end

#output_full_durationBoolean Also known as: output_full_duration?

Optional. If set, Cloud Monitoring will treat the full query duration as the alignment period so that there will be only 1 output value.*Note: This could override the configured alignment period except for the cases where a series of data points are expected, like - XyChart - Scorecard's spark chart Corresponds to the JSON property outputFullDuration

Returns:

  • (Boolean)


2763
2764
2765
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2763

def output_full_duration
  @output_full_duration
end

#prometheus_queryString

A query used to fetch time series with PromQL. Corresponds to the JSON property prometheusQuery

Returns:

  • (String)


2769
2770
2771
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2769

def prometheus_query
  @prometheus_query
end

#time_series_filterGoogle::Apis::MonitoringV1::TimeSeriesFilter

A filter that defines a subset of time series data that is displayed in a widget. Time series data is fetched using the ListTimeSeries (https://cloud. google.com/monitoring/api/ref_v3/rest/v3/projects.timeSeries/list) method. Corresponds to the JSON property timeSeriesFilter



2776
2777
2778
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2776

def time_series_filter
  @time_series_filter
end

#time_series_filter_ratioGoogle::Apis::MonitoringV1::TimeSeriesFilterRatio

A pair of time series filters that define a ratio computation. The output time series is the pair-wise division of each aligned element from the numerator and denominator time series. Corresponds to the JSON property timeSeriesFilterRatio



2783
2784
2785
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2783

def time_series_filter_ratio
  @time_series_filter_ratio
end

#time_series_query_languageString

A query used to fetch time series with MQL. Corresponds to the JSON property timeSeriesQueryLanguage

Returns:

  • (String)


2788
2789
2790
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2788

def time_series_query_language
  @time_series_query_language
end

#unit_overrideString

The unit of data contained in fetched time series. If non-empty, this unit will override any unit that accompanies fetched data. The format is the same as the unit (https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects. metricDescriptors) field in MetricDescriptor. Corresponds to the JSON property unitOverride

Returns:

  • (String)


2796
2797
2798
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2796

def unit_override
  @unit_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2803
2804
2805
2806
2807
2808
2809
2810
2811
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2803

def update!(**args)
  @ops_analytics_query = args[:ops_analytics_query] if args.key?(:ops_analytics_query)
  @output_full_duration = args[:output_full_duration] if args.key?(:output_full_duration)
  @prometheus_query = args[:prometheus_query] if args.key?(:prometheus_query)
  @time_series_filter = args[:time_series_filter] if args.key?(:time_series_filter)
  @time_series_filter_ratio = args[:time_series_filter_ratio] if args.key?(:time_series_filter_ratio)
  @time_series_query_language = args[:time_series_query_language] if args.key?(:time_series_query_language)
  @unit_override = args[:unit_override] if args.key?(:unit_override)
end