Class: Google::Apis::MonitoringV1::TreemapDataSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

The data represented by the treemap. Needs to include the data itself, plus rules on how to organize it hierarchically.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TreemapDataSet

Returns a new instance of TreemapDataSet.



2931
2932
2933
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#breakdownsArray<Google::Apis::MonitoringV1::Breakdown>

Optional. The collection of breakdowns to be applied to the dataset. A breakdown is a way to slice the data. For example, you can break down the data by region. Corresponds to the JSON property breakdowns



2916
2917
2918
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2916

def breakdowns
  @breakdowns
end

#measuresArray<Google::Apis::MonitoringV1::Measure>

Optional. A collection of measures. A measure is a measured value of a property in your data. For example, rainfall in inches, number of units sold, revenue gained, etc. Corresponds to the JSON property measures



2923
2924
2925
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2923

def measures
  @measures
end

#time_series_queryGoogle::Apis::MonitoringV1::TimeSeriesQuery

TimeSeriesQuery collects the set of supported methods for querying time series data from the Stackdriver metrics API. Corresponds to the JSON property timeSeriesQuery



2929
2930
2931
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2929

def time_series_query
  @time_series_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2936
2937
2938
2939
2940
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2936

def update!(**args)
  @breakdowns = args[:breakdowns] if args.key?(:breakdowns)
  @measures = args[:measures] if args.key?(:measures)
  @time_series_query = args[:time_series_query] if args.key?(:time_series_query)
end