Class: Google::Apis::MonitoringV1::VisibilityCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

Condition that determines whether the widget should be displayed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VisibilityCondition

Returns a new instance of VisibilityCondition.



3012
3013
3014
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#template_variable_conditionGoogle::Apis::MonitoringV1::TemplateVariableCondition

A condition whose evaluation is based on the value of a template variable. Corresponds to the JSON property templateVariableCondition



3010
3011
3012
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3010

def template_variable_condition
  @template_variable_condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3017
3018
3019
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3017

def update!(**args)
  @template_variable_condition = args[:template_variable_condition] if args.key?(:template_variable_condition)
end