Class: Google::Apis::MonitoringV1::XyChart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A chart that displays data on a 2D (X and Y axes) plane.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XyChart

Returns a new instance of XyChart.



3163
3164
3165
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chart_optionsGoogle::Apis::MonitoringV1::ChartOptions

Options to control visual rendering of a chart. Corresponds to the JSON property chartOptions



3128
3129
3130
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3128

def chart_options
  @chart_options
end

#data_setsArray<Google::Apis::MonitoringV1::DataSet>

Required. The data displayed in this chart. Corresponds to the JSON property dataSets



3133
3134
3135
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3133

def data_sets
  @data_sets
end

#thresholdsArray<Google::Apis::MonitoringV1::Threshold>

Threshold lines drawn horizontally across the chart. Corresponds to the JSON property thresholds



3138
3139
3140
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3138

def thresholds
  @thresholds
end

#timeshift_durationString

The duration used to display a comparison chart. A comparison chart simultaneously shows values from two similar-length time periods (e.g., week- over-week metrics). The duration must be positive, and it can only be applied to charts with data sets of LINE plot type. Corresponds to the JSON property timeshiftDuration

Returns:

  • (String)


3146
3147
3148
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3146

def timeshift_duration
  @timeshift_duration
end

#x_axisGoogle::Apis::MonitoringV1::Axis

A chart axis. Corresponds to the JSON property xAxis



3151
3152
3153
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3151

def x_axis
  @x_axis
end

#y2_axisGoogle::Apis::MonitoringV1::Axis

A chart axis. Corresponds to the JSON property y2Axis



3156
3157
3158
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3156

def y2_axis
  @y2_axis
end

#y_axisGoogle::Apis::MonitoringV1::Axis

A chart axis. Corresponds to the JSON property yAxis



3161
3162
3163
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3161

def y_axis
  @y_axis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3168
3169
3170
3171
3172
3173
3174
3175
3176
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3168

def update!(**args)
  @chart_options = args[:chart_options] if args.key?(:chart_options)
  @data_sets = args[:data_sets] if args.key?(:data_sets)
  @thresholds = args[:thresholds] if args.key?(:thresholds)
  @timeshift_duration = args[:timeshift_duration] if args.key?(:timeshift_duration)
  @x_axis = args[:x_axis] if args.key?(:x_axis)
  @y2_axis = args[:y2_axis] if args.key?(:y2_axis)
  @y_axis = args[:y_axis] if args.key?(:y_axis)
end