Class: Google::Apis::MonitoringV1::Dashboard
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::Dashboard
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A Google Stackdriver dashboard. Dashboards define the content and layout of pages in the Stackdriver web application.
Instance Attribute Summary collapse
-
#annotations ⇒ Google::Apis::MonitoringV1::DashboardAnnotations
Dashboard-level configuration for annotations Corresponds to the JSON property
annotations. -
#column_layout ⇒ Google::Apis::MonitoringV1::ColumnLayout
A simplified layout that divides the available space into vertical columns and arranges a set of widgets vertically in each column.
-
#dashboard_filters ⇒ Array<Google::Apis::MonitoringV1::DashboardFilter>
Filters to reduce the amount of data charted based on the filter criteria.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other.
-
#grid_layout ⇒ Google::Apis::MonitoringV1::GridLayout
A basic layout divides the available space into vertical columns of equal width and arranges a list of widgets using a row-first strategy.
-
#labels ⇒ Hash<String,String>
Labels applied to the dashboard Corresponds to the JSON property
labels. -
#mosaic_layout ⇒ Google::Apis::MonitoringV1::MosaicLayout
A mosaic layout divides the available space into a grid of blocks, and overlays the grid with tiles.
-
#name ⇒ String
Identifier.
-
#row_layout ⇒ Google::Apis::MonitoringV1::RowLayout
A simplified layout that divides the available space into rows and arranges a set of widgets horizontally in each row.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Dashboard
constructor
A new instance of Dashboard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Dashboard
Returns a new instance of Dashboard.
476 477 478 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Google::Apis::MonitoringV1::DashboardAnnotations
Dashboard-level configuration for annotations
Corresponds to the JSON property annotations
419 420 421 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 419 def annotations @annotations end |
#column_layout ⇒ Google::Apis::MonitoringV1::ColumnLayout
A simplified layout that divides the available space into vertical columns and
arranges a set of widgets vertically in each column.
Corresponds to the JSON property columnLayout
425 426 427 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 425 def column_layout @column_layout end |
#dashboard_filters ⇒ Array<Google::Apis::MonitoringV1::DashboardFilter>
Filters to reduce the amount of data charted based on the filter criteria.
Corresponds to the JSON property dashboardFilters
430 431 432 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 430 def dashboard_filters @dashboard_filters end |
#display_name ⇒ String
Required. The mutable, human-readable name.
Corresponds to the JSON property displayName
435 436 437 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 435 def display_name @display_name end |
#etag ⇒ String
etag is used for optimistic concurrency control as a way to help prevent
simultaneous updates of a policy from overwriting each other. An etag is
returned in the response to GetDashboard, and users are expected to put that
etag in the request to UpdateDashboard to ensure that their change will be
applied to the same version of the Dashboard configuration. The field should
not be passed during dashboard creation.
Corresponds to the JSON property etag
445 446 447 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 445 def etag @etag end |
#grid_layout ⇒ Google::Apis::MonitoringV1::GridLayout
A basic layout divides the available space into vertical columns of equal
width and arranges a list of widgets using a row-first strategy.
Corresponds to the JSON property gridLayout
451 452 453 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 451 def grid_layout @grid_layout end |
#labels ⇒ Hash<String,String>
Labels applied to the dashboard
Corresponds to the JSON property labels
456 457 458 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 456 def labels @labels end |
#mosaic_layout ⇒ Google::Apis::MonitoringV1::MosaicLayout
A mosaic layout divides the available space into a grid of blocks, and
overlays the grid with tiles. Unlike GridLayout, tiles may span multiple grid
blocks and can be placed at arbitrary locations in the grid.
Corresponds to the JSON property mosaicLayout
463 464 465 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 463 def mosaic_layout @mosaic_layout end |
#name ⇒ String
Identifier. The resource name of the dashboard.
Corresponds to the JSON property name
468 469 470 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 468 def name @name end |
#row_layout ⇒ Google::Apis::MonitoringV1::RowLayout
A simplified layout that divides the available space into rows and arranges a
set of widgets horizontally in each row.
Corresponds to the JSON property rowLayout
474 475 476 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 474 def row_layout @row_layout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 481 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @column_layout = args[:column_layout] if args.key?(:column_layout) @dashboard_filters = args[:dashboard_filters] if args.key?(:dashboard_filters) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @grid_layout = args[:grid_layout] if args.key?(:grid_layout) @labels = args[:labels] if args.key?(:labels) @mosaic_layout = args[:mosaic_layout] if args.key?(:mosaic_layout) @name = args[:name] if args.key?(:name) @row_layout = args[:row_layout] if args.key?(:row_layout) end |