Class: Google::Apis::MonitoringV1::DashboardAnnotations
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::DashboardAnnotations
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
Dashboard-level configuration for annotations
Instance Attribute Summary collapse
-
#default_resource_names ⇒ Array<String>
Dashboard level defaults for names of logging resources to search for events.
-
#event_annotations ⇒ Array<Google::Apis::MonitoringV1::EventAnnotation>
List of annotation configurations for this dashboard.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DashboardAnnotations
constructor
A new instance of DashboardAnnotations.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DashboardAnnotations
Returns a new instance of DashboardAnnotations.
543 544 545 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_resource_names ⇒ Array<String>
Dashboard level defaults for names of logging resources to search for events.
Currently only projects are supported. Each individual EventAnnotation may
have its own overrides. If both this field and the per annotation field is
empty, then the scoping project is used. Limit: 50 projects. For example: “
projects/some-project-id”
Corresponds to the JSON property defaultResourceNames
535 536 537 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 535 def default_resource_names @default_resource_names end |
#event_annotations ⇒ Array<Google::Apis::MonitoringV1::EventAnnotation>
List of annotation configurations for this dashboard. Each entry specifies one
event type.
Corresponds to the JSON property eventAnnotations
541 542 543 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 541 def event_annotations @event_annotations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
548 549 550 551 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 548 def update!(**args) @default_resource_names = args[:default_resource_names] if args.key?(:default_resource_names) @event_annotations = args[:event_annotations] if args.key?(:event_annotations) end |