Class: Google::Apis::MonitoringV1::DataSet
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::DataSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
Groups a time series query definition with charting options.
Instance Attribute Summary collapse
-
#breakdowns ⇒ Array<Google::Apis::MonitoringV1::Breakdown>
Optional.
-
#dimensions ⇒ Array<Google::Apis::MonitoringV1::Dimension>
Optional.
-
#legend_template ⇒ String
A template string for naming TimeSeries in the resulting data set.
-
#measures ⇒ Array<Google::Apis::MonitoringV1::Measure>
Optional.
-
#min_alignment_period ⇒ String
Optional.
-
#plot_type ⇒ String
How this data should be plotted on the chart.
-
#sort ⇒ Array<Google::Apis::MonitoringV1::ColumnSortingOptions>
Optional.
-
#target_axis ⇒ String
Optional.
-
#time_series_query ⇒ Google::Apis::MonitoringV1::TimeSeriesQuery
TimeSeriesQuery collects the set of supported methods for querying time series data from the Stackdriver metrics API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSet
constructor
A new instance of DataSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSet
Returns a new instance of DataSet.
653 654 655 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#breakdowns ⇒ Array<Google::Apis::MonitoringV1::Breakdown>
Optional. The collection of breakdowns to be applied to the dataset.
Corresponds to the JSON property breakdowns
600 601 602 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 600 def breakdowns @breakdowns end |
#dimensions ⇒ Array<Google::Apis::MonitoringV1::Dimension>
Optional. A collection of dimension columns.
Corresponds to the JSON property dimensions
605 606 607 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 605 def dimensions @dimensions end |
#legend_template ⇒ String
A template string for naming TimeSeries in the resulting data set. This should
be a string with interpolations of the form $label_name, which will resolve
to the label's value.
Corresponds to the JSON property legendTemplate
612 613 614 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 612 def legend_template @legend_template end |
#measures ⇒ Array<Google::Apis::MonitoringV1::Measure>
Optional. A collection of measures.
Corresponds to the JSON property measures
617 618 619 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 617 def measures @measures end |
#min_alignment_period ⇒ String
Optional. The lower bound on data point frequency for this data set,
implemented by specifying the minimum alignment period to use in a time series
query. For example, if the data is published once every 10 minutes, the
min_alignment_period should be at least 10 minutes. It would not make sense to
fetch and align data at one minute intervals.For PromQL queries, this field is
used to set the minimum interval for the query step, controlling data
granularity. Larger values can improve performance on long time ranges. See
Querying Basics and Range Queries for more details on the PromQL step.
Corresponds to the JSON property minAlignmentPeriod
629 630 631 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 629 def min_alignment_period @min_alignment_period end |
#plot_type ⇒ String
How this data should be plotted on the chart.
Corresponds to the JSON property plotType
634 635 636 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 634 def plot_type @plot_type end |
#sort ⇒ Array<Google::Apis::MonitoringV1::ColumnSortingOptions>
Optional. A collection of sort options, affects the order of the data and
legend.
Corresponds to the JSON property sort
640 641 642 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 640 def sort @sort end |
#target_axis ⇒ String
Optional. The target axis to use for plotting the metric.
Corresponds to the JSON property targetAxis
645 646 647 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 645 def target_axis @target_axis end |
#time_series_query ⇒ Google::Apis::MonitoringV1::TimeSeriesQuery
TimeSeriesQuery collects the set of supported methods for querying time series
data from the Stackdriver metrics API.
Corresponds to the JSON property timeSeriesQuery
651 652 653 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 651 def time_series_query @time_series_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
658 659 660 661 662 663 664 665 666 667 668 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 658 def update!(**args) @breakdowns = args[:breakdowns] if args.key?(:breakdowns) @dimensions = args[:dimensions] if args.key?(:dimensions) @legend_template = args[:legend_template] if args.key?(:legend_template) @measures = args[:measures] if args.key?(:measures) @min_alignment_period = args[:min_alignment_period] if args.key?(:min_alignment_period) @plot_type = args[:plot_type] if args.key?(:plot_type) @sort = args[:sort] if args.key?(:sort) @target_axis = args[:target_axis] if args.key?(:target_axis) @time_series_query = args[:time_series_query] if args.key?(:time_series_query) end |