Class: Google::Apis::MonitoringV1::DataSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

Groups a time series query definition with charting options.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSet

Returns a new instance of DataSet.



679
680
681
# File 'lib/google/apis/monitoring_v1/classes.rb', line 679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#breakdownsArray<Google::Apis::MonitoringV1::Breakdown>

Optional. The collection of breakdowns to be applied to the dataset. Corresponds to the JSON property breakdowns



629
630
631
# File 'lib/google/apis/monitoring_v1/classes.rb', line 629

def breakdowns
  @breakdowns
end

#dimensionsArray<Google::Apis::MonitoringV1::Dimension>

Optional. A collection of dimension columns. Corresponds to the JSON property dimensions



634
635
636
# File 'lib/google/apis/monitoring_v1/classes.rb', line 634

def dimensions
  @dimensions
end

#legend_templateString

A template string for naming TimeSeries in the resulting data set. This should be a string with interpolations of the form $label_name, which will resolve to the label's value. Corresponds to the JSON property legendTemplate

Returns:

  • (String)


641
642
643
# File 'lib/google/apis/monitoring_v1/classes.rb', line 641

def legend_template
  @legend_template
end

#measuresArray<Google::Apis::MonitoringV1::Measure>

Optional. A collection of measures. Corresponds to the JSON property measures



646
647
648
# File 'lib/google/apis/monitoring_v1/classes.rb', line 646

def measures
  @measures
end

#min_alignment_periodString

Optional. The lower bound on data point frequency for this data set, implemented by specifying the minimum alignment period to use in a time series query For example, if the data is published once every 10 minutes, the min_alignment_period should be at least 10 minutes. It would not make sense to fetch and align data at one minute intervals. Corresponds to the JSON property minAlignmentPeriod

Returns:

  • (String)


655
656
657
# File 'lib/google/apis/monitoring_v1/classes.rb', line 655

def min_alignment_period
  @min_alignment_period
end

#plot_typeString

How this data should be plotted on the chart. Corresponds to the JSON property plotType

Returns:

  • (String)


660
661
662
# File 'lib/google/apis/monitoring_v1/classes.rb', line 660

def plot_type
  @plot_type
end

#sortArray<Google::Apis::MonitoringV1::ColumnSortingOptions>

Optional. A collection of sort options, affects the order of the data and legend. Corresponds to the JSON property sort



666
667
668
# File 'lib/google/apis/monitoring_v1/classes.rb', line 666

def sort
  @sort
end

#target_axisString

Optional. The target axis to use for plotting the metric. Corresponds to the JSON property targetAxis

Returns:

  • (String)


671
672
673
# File 'lib/google/apis/monitoring_v1/classes.rb', line 671

def target_axis
  @target_axis
end

#time_series_queryGoogle::Apis::MonitoringV1::TimeSeriesQuery

TimeSeriesQuery collects the set of supported methods for querying time series data from the Stackdriver metrics API. Corresponds to the JSON property timeSeriesQuery



677
678
679
# File 'lib/google/apis/monitoring_v1/classes.rb', line 677

def time_series_query
  @time_series_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



684
685
686
687
688
689
690
691
692
693
694
# File 'lib/google/apis/monitoring_v1/classes.rb', line 684

def update!(**args)
  @breakdowns = args[:breakdowns] if args.key?(:breakdowns)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @legend_template = args[:legend_template] if args.key?(:legend_template)
  @measures = args[:measures] if args.key?(:measures)
  @min_alignment_period = args[:min_alignment_period] if args.key?(:min_alignment_period)
  @plot_type = args[:plot_type] if args.key?(:plot_type)
  @sort = args[:sort] if args.key?(:sort)
  @target_axis = args[:target_axis] if args.key?(:target_axis)
  @time_series_query = args[:time_series_query] if args.key?(:time_series_query)
end