Class: Google::Apis::MonitoringV1::ErrorReportingPanel
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::ErrorReportingPanel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A widget that displays a list of error groups.
Instance Attribute Summary collapse
-
#project_names ⇒ Array<String>
The resource name of the Google Cloud Platform project.
-
#services ⇒ Array<String>
An identifier of the service, such as the name of the executable, job, or Google App Engine service name.
-
#versions ⇒ Array<String>
Represents the source code version that the developer provided, which could represent a version label or a Git SHA-1 hash, for example.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ErrorReportingPanel
constructor
A new instance of ErrorReportingPanel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ErrorReportingPanel
Returns a new instance of ErrorReportingPanel.
852 853 854 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 852 def initialize(**args) update!(**args) end |
Instance Attribute Details
#project_names ⇒ Array<String>
The resource name of the Google Cloud Platform project. Written as projects/
projectID or projects/projectNumber, where projectID and projectNumber
can be found in the Google Cloud console (https://support.google.com/cloud/
answer/6158840).Examples: projects/my-project-123, projects/5551234.
Corresponds to the JSON property projectNames
833 834 835 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 833 def project_names @project_names end |
#services ⇒ Array<String>
An identifier of the service, such as the name of the executable, job, or
Google App Engine service name. This field is expected to have a low number of
values that are relatively stable over time, as opposed to version, which can
be changed whenever new code is deployed.Contains the service name for error
reports extracted from Google App Engine logs or default if the App Engine
default service is used.
Corresponds to the JSON property services
843 844 845 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 843 def services @services end |
#versions ⇒ Array<String>
Represents the source code version that the developer provided, which could
represent a version label or a Git SHA-1 hash, for example. For App Engine
standard environment, the version is set to the version of the app.
Corresponds to the JSON property versions
850 851 852 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 850 def versions @versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
857 858 859 860 861 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 857 def update!(**args) @project_names = args[:project_names] if args.key?(:project_names) @services = args[:services] if args.key?(:services) @versions = args[:versions] if args.key?(:versions) end |