Class: Google::Apis::MonitoringV1::EventAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::EventAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
Annotation configuration for one event type on a dashboard
Instance Attribute Summary collapse
-
#display_name ⇒ String
Solely for UI display.
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether or not to show the events on the dashboard by default Corresponds to the JSON property
enabled. -
#event_type ⇒ String
The type of event to display.
-
#filter ⇒ String
string filtering the events - event dependant.
-
#resource_names ⇒ Array<String>
Per annotation level override for the names of logging resources to search for events.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventAnnotation
constructor
A new instance of EventAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventAnnotation
Returns a new instance of EventAnnotation.
873 874 875 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 873 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Solely for UI display. Should not be used programmatically.
Corresponds to the JSON property displayName
845 846 847 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 845 def display_name @display_name end |
#enabled ⇒ Boolean Also known as: enabled?
Whether or not to show the events on the dashboard by default
Corresponds to the JSON property enabled
850 851 852 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 850 def enabled @enabled end |
#event_type ⇒ String
The type of event to display.
Corresponds to the JSON property eventType
856 857 858 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 856 def event_type @event_type end |
#filter ⇒ String
string filtering the events - event dependant. Example values: "resource.
labels.pod_name = 'pod-1'" "protoPayload.authenticationInfo.principalEmail='
user@example.com'"
Corresponds to the JSON property filter
863 864 865 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 863 def filter @filter end |
#resource_names ⇒ Array<String>
Per annotation level override for the names of logging resources to search for
events. Currently only projects are supported. If both this field and the per
annotation field is empty, it will default to the host project. Limit: 50
projects. For example: “projects/another-project-id”
Corresponds to the JSON property resourceNames
871 872 873 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 871 def resource_names @resource_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
878 879 880 881 882 883 884 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 878 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @enabled = args[:enabled] if args.key?(:enabled) @event_type = args[:event_type] if args.key?(:event_type) @filter = args[:filter] if args.key?(:filter) @resource_names = args[:resource_names] if args.key?(:resource_names) end |