Class: Google::Apis::MonitoringV1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A single field of a message type.New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



974
975
976
# File 'lib/google/apis/monitoring_v1/classes.rb', line 974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


924
925
926
# File 'lib/google/apis/monitoring_v1/classes.rb', line 924

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


929
930
931
# File 'lib/google/apis/monitoring_v1/classes.rb', line 929

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


934
935
936
# File 'lib/google/apis/monitoring_v1/classes.rb', line 934

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


939
940
941
# File 'lib/google/apis/monitoring_v1/classes.rb', line 939

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


944
945
946
# File 'lib/google/apis/monitoring_v1/classes.rb', line 944

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


949
950
951
# File 'lib/google/apis/monitoring_v1/classes.rb', line 949

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


955
956
957
# File 'lib/google/apis/monitoring_v1/classes.rb', line 955

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::MonitoringV1::Option>

The protocol buffer options. Corresponds to the JSON property options



960
961
962
# File 'lib/google/apis/monitoring_v1/classes.rb', line 960

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


965
966
967
# File 'lib/google/apis/monitoring_v1/classes.rb', line 965

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


972
973
974
# File 'lib/google/apis/monitoring_v1/classes.rb', line 972

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



979
980
981
982
983
984
985
986
987
988
989
990
# File 'lib/google/apis/monitoring_v1/classes.rb', line 979

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end