Class: Google::Apis::MonitoringV1::GaugeView
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::GaugeView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A gauge chart shows where the current value sits within a pre-defined range. The upper and lower bounds should define the possible range of values for the scorecard's query (inclusive).
Instance Attribute Summary collapse
-
#lower_bound ⇒ Float
The lower bound for this gauge chart.
-
#upper_bound ⇒ Float
The upper bound for this gauge chart.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GaugeView
constructor
A new instance of GaugeView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GaugeView
Returns a new instance of GaugeView.
1031 1032 1033 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lower_bound ⇒ Float
The lower bound for this gauge chart. The value of the chart should always be
greater than or equal to this.
Corresponds to the JSON property lowerBound
1023 1024 1025 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1023 def lower_bound @lower_bound end |
#upper_bound ⇒ Float
The upper bound for this gauge chart. The value of the chart should always be
less than or equal to this.
Corresponds to the JSON property upperBound
1029 1030 1031 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1029 def upper_bound @upper_bound end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1036 1037 1038 1039 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1036 def update!(**args) @lower_bound = args[:lower_bound] if args.key?(:lower_bound) @upper_bound = args[:upper_bound] if args.key?(:upper_bound) end |