Class: Google::Apis::MonitoringV1::Interval
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::Interval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#start_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Interval
constructor
A new instance of Interval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Interval
Returns a new instance of Interval.
1140 1141 1142 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. Exclusive end of the interval.If specified, a Timestamp matching
this interval will have to be before the end.
Corresponds to the JSON property endTime
1132 1133 1134 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1132 def end_time @end_time end |
#start_time ⇒ String
Optional. Inclusive start of the interval.If specified, a Timestamp matching
this interval will have to be the same or after the start.
Corresponds to the JSON property startTime
1138 1139 1140 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1138 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1145 1146 1147 1148 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1145 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |