Class: Google::Apis::MonitoringV1::LogsPanel
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::LogsPanel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A widget that displays a stream of log.
Instance Attribute Summary collapse
-
#filter ⇒ String
A filter that chooses which log entries to return.
-
#resource_names ⇒ Array<String>
The names of logging resources to collect logs for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LogsPanel
constructor
A new instance of LogsPanel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LogsPanel
Returns a new instance of LogsPanel.
1216 1217 1218 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
A filter that chooses which log entries to return. See Advanced Logs Queries (
https://cloud.google.com/logging/docs/view/advanced-queries). Only log entries
that match the filter are returned. An empty filter matches all log entries.
Corresponds to the JSON property filter
1207 1208 1209 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1207 def filter @filter end |
#resource_names ⇒ Array<String>
The names of logging resources to collect logs for. Currently projects and
storage views are supported. If empty, the widget will default to the host
project.
Corresponds to the JSON property resourceNames
1214 1215 1216 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1214 def resource_names @resource_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1221 1222 1223 1224 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1221 def update!(**args) @filter = args[:filter] if args.key?(:filter) @resource_names = args[:resource_names] if args.key?(:resource_names) end |