Class: Google::Apis::MonitoringV1::MetricsScope
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::MetricsScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
Represents a Metrics Scope (https://cloud.google.com/monitoring/settings# concept-scope) in Cloud Monitoring, which specifies one or more Google projects and zero or more AWS accounts to monitor together.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#monitored_projects ⇒ Array<Google::Apis::MonitoringV1::MonitoredProject>
Output only.
-
#name ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricsScope
constructor
A new instance of MetricsScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricsScope
Returns a new instance of MetricsScope.
1285 1286 1287 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when this Metrics Scope was created.
Corresponds to the JSON property createTime
1265 1266 1267 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1265 def create_time @create_time end |
#monitored_projects ⇒ Array<Google::Apis::MonitoringV1::MonitoredProject>
Output only. The list of projects monitored by this Metrics Scope.
Corresponds to the JSON property monitoredProjects
1270 1271 1272 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1270 def monitored_projects @monitored_projects end |
#name ⇒ String
Immutable. The resource name of the Monitoring Metrics Scope. On input, the
resource name can be specified with the scoping project ID or number. On
output, the resource name is specified with the scoping project number.
Example: locations/global/metricsScopes/SCOPING_PROJECT_ID_OR_NUMBER
Corresponds to the JSON property name
1278 1279 1280 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1278 def name @name end |
#update_time ⇒ String
Output only. The time when this Metrics Scope record was last updated.
Corresponds to the JSON property updateTime
1283 1284 1285 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1283 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1290 1291 1292 1293 1294 1295 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1290 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @monitored_projects = args[:monitored_projects] if args.key?(:monitored_projects) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |