Class: Google::Apis::MonitoringV1::MonitoredProject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A project being monitored (https://cloud.google.com/monitoring/settings/ multiple-projects#create-multi) by a Metrics Scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MonitoredProject

Returns a new instance of MonitoredProject.



1349
1350
1351
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when this MonitoredProject was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1332
1333
1334
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1332

def create_time
  @create_time
end

#is_tombstonedBoolean Also known as: is_tombstoned?

Output only. Set if the project has been tombstoned by the user. Corresponds to the JSON property isTombstoned

Returns:

  • (Boolean)


1337
1338
1339
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1337

def is_tombstoned
  @is_tombstoned
end

#nameString

Immutable. The resource name of the MonitoredProject. On input, the resource name includes the scoping project ID and monitored project ID. On output, it contains the equivalent project numbers. Example: locations/global/ metricsScopes/SCOPING_PROJECT_ID_OR_NUMBER/projects/ MONITORED_PROJECT_ID_OR_NUMBER Corresponds to the JSON property name

Returns:

  • (String)


1347
1348
1349
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1347

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1354
1355
1356
1357
1358
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1354

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @is_tombstoned = args[:is_tombstoned] if args.key?(:is_tombstoned)
  @name = args[:name] if args.key?(:name)
end