Class: Google::Apis::MonitoringV1::MosaicLayout
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::MosaicLayout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A mosaic layout divides the available space into a grid of blocks, and overlays the grid with tiles. Unlike GridLayout, tiles may span multiple grid blocks and can be placed at arbitrary locations in the grid.
Instance Attribute Summary collapse
-
#columns ⇒ Fixnum
The number of columns in the mosaic grid.
-
#tiles ⇒ Array<Google::Apis::MonitoringV1::Tile>
The tiles to display.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MosaicLayout
constructor
A new instance of MosaicLayout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MosaicLayout
Returns a new instance of MosaicLayout.
1392 1393 1394 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Fixnum
The number of columns in the mosaic grid. The number of columns must be
between 1 and 48, inclusive.
Corresponds to the JSON property columns
1385 1386 1387 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1385 def columns @columns end |
#tiles ⇒ Array<Google::Apis::MonitoringV1::Tile>
The tiles to display.
Corresponds to the JSON property tiles
1390 1391 1392 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1390 def tiles @tiles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1397 1398 1399 1400 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1397 def update!(**args) @columns = args[:columns] if args.key?(:columns) @tiles = args[:tiles] if args.key?(:tiles) end |