Class: Google::Apis::MonitoringV1::QueryInstantRequest
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::QueryInstantRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
QueryInstantRequest holds all parameters of the Prometheus upstream instant query API plus GCM specific parameters.
Instance Attribute Summary collapse
-
#query ⇒ String
A PromQL query string.
-
#time ⇒ String
The single point in time to evaluate the query for.
-
#timeout ⇒ String
An upper bound timeout for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryInstantRequest
constructor
A new instance of QueryInstantRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryInstantRequest
Returns a new instance of QueryInstantRequest.
1781 1782 1783 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query ⇒ String
A PromQL query string. Query language documentation: https://prometheus.io/
docs/prometheus/latest/querying/basics/.
Corresponds to the JSON property query
1764 1765 1766 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1764 def query @query end |
#time ⇒ String
The single point in time to evaluate the query for. Either floating point UNIX
seconds or RFC3339 formatted timestamp.
Corresponds to the JSON property time
1770 1771 1772 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1770 def time @time end |
#timeout ⇒ String
An upper bound timeout for the query. Either a Prometheus duration string (
https://prometheus.io/docs/prometheus/latest/querying/basics/#time-durations)
or floating point seconds. This non-standard encoding must be used for
compatibility with the open source API. Clients may still implement timeouts
at the connection level while ignoring this field.
Corresponds to the JSON property timeout
1779 1780 1781 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1779 def timeout @timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1786 1787 1788 1789 1790 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1786 def update!(**args) @query = args[:query] if args.key?(:query) @time = args[:time] if args.key?(:time) @timeout = args[:timeout] if args.key?(:timeout) end |