Class: Google::Apis::MonitoringV1::QueryInstantRequest
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::QueryInstantRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
QueryInstantRequest holds all parameters of the Prometheus upstream instant query API plus GCM specific parameters.
Instance Attribute Summary collapse
-
#query ⇒ String
A PromQL query string.
-
#time ⇒ String
The single point in time to evaluate the query for.
-
#timeout ⇒ String
An upper bound timeout for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryInstantRequest
constructor
A new instance of QueryInstantRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryInstantRequest
Returns a new instance of QueryInstantRequest.
1795 1796 1797 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query ⇒ String
A PromQL query string. Query language documentation: https://prometheus.io/
docs/prometheus/latest/querying/basics/.
Corresponds to the JSON property query
1778 1779 1780 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1778 def query @query end |
#time ⇒ String
The single point in time to evaluate the query for. Either floating point UNIX
seconds or RFC3339 formatted timestamp.
Corresponds to the JSON property time
1784 1785 1786 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1784 def time @time end |
#timeout ⇒ String
An upper bound timeout for the query. Either a Prometheus duration string (
https://prometheus.io/docs/prometheus/latest/querying/basics/#time-durations)
or floating point seconds. This non-standard encoding must be used for
compatibility with the open source API. Clients may still implement timeouts
at the connection level while ignoring this field.
Corresponds to the JSON property timeout
1793 1794 1795 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1793 def timeout @timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1800 1801 1802 1803 1804 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1800 def update!(**args) @query = args[:query] if args.key?(:query) @time = args[:time] if args.key?(:time) @timeout = args[:timeout] if args.key?(:timeout) end |