Class: Google::Apis::MonitoringV1::QueryRangeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

QueryRangeRequest holds all parameters of the Prometheus upstream range query API plus GCM specific parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryRangeRequest

Returns a new instance of QueryRangeRequest.



1883
1884
1885
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1883

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endString

The end time to evaluate the query for. Either floating point UNIX seconds or RFC3339 formatted timestamp. Corresponds to the JSON property end

Returns:

  • (String)


1851
1852
1853
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1851

def end
  @end
end

#queryString

A PromQL query string. Query language documentation: https://prometheus.io/ docs/prometheus/latest/querying/basics/. Corresponds to the JSON property query

Returns:

  • (String)


1857
1858
1859
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1857

def query
  @query
end

#startString

The start time to evaluate the query for. Either floating point UNIX seconds or RFC3339 formatted timestamp. Corresponds to the JSON property start

Returns:

  • (String)


1863
1864
1865
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1863

def start
  @start
end

#stepString

The resolution of query result. Either a Prometheus duration string (https:// prometheus.io/docs/prometheus/latest/querying/basics/#time-durations) or floating point seconds. This non-standard encoding must be used for compatibility with the open source API. Clients may still implement timeouts at the connection level while ignoring this field. Corresponds to the JSON property step

Returns:

  • (String)


1872
1873
1874
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1872

def step
  @step
end

#timeoutString

An upper bound timeout for the query. Either a Prometheus duration string ( https://prometheus.io/docs/prometheus/latest/querying/basics/#time-durations) or floating point seconds. This non-standard encoding must be used for compatibility with the open source API. Clients may still implement timeouts at the connection level while ignoring this field. Corresponds to the JSON property timeout

Returns:

  • (String)


1881
1882
1883
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1881

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1888
1889
1890
1891
1892
1893
1894
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1888

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @query = args[:query] if args.key?(:query)
  @start = args[:start] if args.key?(:start)
  @step = args[:step] if args.key?(:step)
  @timeout = args[:timeout] if args.key?(:timeout)
end