Class: Google::Apis::MonitoringV1::Row
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::Row
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
Defines the layout properties and content for a row.
Instance Attribute Summary collapse
-
#weight ⇒ Fixnum
The relative weight of this row.
-
#widgets ⇒ Array<Google::Apis::MonitoringV1::Widget>
The display widgets arranged horizontally in this row.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Row
constructor
A new instance of Row.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Row
Returns a new instance of Row.
1989 1990 1991 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#weight ⇒ Fixnum
The relative weight of this row. The row weight is used to adjust the height
of rows on the screen (relative to peers). Greater the weight, greater the
height of the row on the screen. If omitted, a value of 1 is used while
rendering.
Corresponds to the JSON property weight
1982 1983 1984 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1982 def weight @weight end |
#widgets ⇒ Array<Google::Apis::MonitoringV1::Widget>
The display widgets arranged horizontally in this row.
Corresponds to the JSON property widgets
1987 1988 1989 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1987 def @widgets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1994 1995 1996 1997 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1994 def update!(**args) @weight = args[:weight] if args.key?(:weight) @widgets = args[:widgets] if args.key?(:widgets) end |