Class: Google::Apis::MonitoringV1::RowLayout

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A simplified layout that divides the available space into rows and arranges a set of widgets horizontally in each row.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RowLayout

Returns a new instance of RowLayout.



1984
1985
1986
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1984

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rowsArray<Google::Apis::MonitoringV1::Row>

The rows of content to display. Corresponds to the JSON property rows



1982
1983
1984
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1982

def rows
  @rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1989
1990
1991
# File 'lib/google/apis/monitoring_v1/classes.rb', line 1989

def update!(**args)
  @rows = args[:rows] if args.key?(:rows)
end