Class: Google::Apis::MonitoringV1::SectionHeader
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::SectionHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A widget that defines a new section header. Sections populate a table of contents and allow easier navigation of long-form content.
Instance Attribute Summary collapse
-
#divider_below ⇒ Boolean
(also: #divider_below?)
Whether to insert a divider below the section in the table of contents Corresponds to the JSON property
dividerBelow. -
#subtitle ⇒ String
The subtitle of the section Corresponds to the JSON property
subtitle.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SectionHeader
constructor
A new instance of SectionHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SectionHeader
Returns a new instance of SectionHeader.
2098 2099 2100 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#divider_below ⇒ Boolean Also known as: divider_below?
Whether to insert a divider below the section in the table of contents
Corresponds to the JSON property dividerBelow
2090 2091 2092 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2090 def divider_below @divider_below end |
#subtitle ⇒ String
The subtitle of the section
Corresponds to the JSON property subtitle
2096 2097 2098 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2096 def subtitle @subtitle end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2103 2104 2105 2106 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2103 def update!(**args) @divider_below = args[:divider_below] if args.key?(:divider_below) @subtitle = args[:subtitle] if args.key?(:subtitle) end |