Class: Google::Apis::MonitoringV1::SingleViewGroup
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::SingleViewGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A widget that groups the other widgets by using a dropdown menu. All widgets that are within the area spanned by the grouping widget are considered member widgets.
Instance Attribute Summary collapse
-
#display_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleViewGroup
constructor
A new instance of SingleViewGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleViewGroup
Returns a new instance of SingleViewGroup.
2146 2147 2148 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_type ⇒ String
Optional. Determines how the widget selector will be displayed.
Corresponds to the JSON property displayType
2144 2145 2146 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2144 def display_type @display_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2151 2152 2153 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2151 def update!(**args) @display_type = args[:display_type] if args.key?(:display_type) end |