Class: Google::Apis::MonitoringV1::SparkChartView
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::SparkChartView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A sparkChart is a small chart suitable for inclusion in a table-cell or inline in text. This message contains the configuration for a sparkChart to show up on a Scorecard, showing recent trends of the scorecard's timeseries.
Instance Attribute Summary collapse
-
#min_alignment_period ⇒ String
The lower bound on data point frequency in the chart implemented by specifying the minimum alignment period to use in a time series query.
-
#spark_chart_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SparkChartView
constructor
A new instance of SparkChartView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SparkChartView
Returns a new instance of SparkChartView.
2199 2200 2201 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#min_alignment_period ⇒ String
The lower bound on data point frequency in the chart implemented by specifying
the minimum alignment period to use in a time series query. For example, if
the data is published once every 10 minutes it would not make sense to fetch
and align data at one minute intervals. This field is optional and exists only
as a hint.For PromQL queries, this field is used to set the minimum interval
for the query step, controlling data granularity. Larger values can improve
performance on long time ranges. See Querying Basics and Range Queries for
more details on the PromQL step.
Corresponds to the JSON property minAlignmentPeriod
2192 2193 2194 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2192 def min_alignment_period @min_alignment_period end |
#spark_chart_type ⇒ String
Required. The type of sparkchart to show in this chartView.
Corresponds to the JSON property sparkChartType
2197 2198 2199 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2197 def spark_chart_type @spark_chart_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2204 2205 2206 2207 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2204 def update!(**args) @min_alignment_period = args[:min_alignment_period] if args.key?(:min_alignment_period) @spark_chart_type = args[:spark_chart_type] if args.key?(:spark_chart_type) end |