Class: Google::Apis::MonitoringV1::Treemap
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::Treemap
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
A widget that displays hierarchical data as a treemap.
Instance Attribute Summary collapse
-
#data_sets ⇒ Array<Google::Apis::MonitoringV1::TreemapDataSet>
Required.
-
#treemap_hierarchy ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Treemap
constructor
A new instance of Treemap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Treemap
Returns a new instance of Treemap.
2862 2863 2864 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_sets ⇒ Array<Google::Apis::MonitoringV1::TreemapDataSet>
Required. The collection of datasets used to construct and populate the
treemap. For the rendered treemap rectangles: Color is determined by the
aggregated value for each grouping. Size is proportional to the count of time
series aggregated within that rectangle's segment.
Corresponds to the JSON property dataSets
2855 2856 2857 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2855 def data_sets @data_sets end |
#treemap_hierarchy ⇒ Array<String>
Required. Ordered labels representing the hierarchical treemap structure.
Corresponds to the JSON property treemapHierarchy
2860 2861 2862 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2860 def treemap_hierarchy @treemap_hierarchy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2867 2868 2869 2870 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2867 def update!(**args) @data_sets = args[:data_sets] if args.key?(:data_sets) @treemap_hierarchy = args[:treemap_hierarchy] if args.key?(:treemap_hierarchy) end |