Class: Google::Apis::MonitoringV1::Treemap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

A widget that displays hierarchical data as a treemap.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Treemap

Returns a new instance of Treemap.



2885
2886
2887
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_setsArray<Google::Apis::MonitoringV1::TreemapDataSet>

Required. The collection of datasets used to construct and populate the treemap. For the rendered treemap rectangles: Color is determined by the aggregated value for each grouping. Size is proportional to the count of time series aggregated within that rectangle's segment. Corresponds to the JSON property dataSets



2878
2879
2880
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2878

def data_sets
  @data_sets
end

#treemap_hierarchyArray<String>

Required. Ordered labels representing the hierarchical treemap structure. Corresponds to the JSON property treemapHierarchy

Returns:

  • (Array<String>)


2883
2884
2885
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2883

def treemap_hierarchy
  @treemap_hierarchy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2890
2891
2892
2893
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2890

def update!(**args)
  @data_sets = args[:data_sets] if args.key?(:data_sets)
  @treemap_hierarchy = args[:treemap_hierarchy] if args.key?(:treemap_hierarchy)
end