Class: Google::Apis::MonitoringV1::TreemapDataSet
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::TreemapDataSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
The data represented by the treemap. Needs to include the data itself, plus rules on how to organize it hierarchically.
Instance Attribute Summary collapse
-
#breakdowns ⇒ Array<Google::Apis::MonitoringV1::Breakdown>
Optional.
-
#measures ⇒ Array<Google::Apis::MonitoringV1::Measure>
Optional.
-
#time_series_query ⇒ Google::Apis::MonitoringV1::TimeSeriesQuery
TimeSeriesQuery collects the set of supported methods for querying time series data from the Stackdriver metrics API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TreemapDataSet
constructor
A new instance of TreemapDataSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TreemapDataSet
Returns a new instance of TreemapDataSet.
2921 2922 2923 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#breakdowns ⇒ Array<Google::Apis::MonitoringV1::Breakdown>
Optional. The collection of breakdowns to be applied to the dataset. A
breakdown is a way to slice the data. For example, you can break down the data
by region.
Corresponds to the JSON property breakdowns
2906 2907 2908 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2906 def breakdowns @breakdowns end |
#measures ⇒ Array<Google::Apis::MonitoringV1::Measure>
Optional. A collection of measures. A measure is a measured value of a
property in your data. For example, rainfall in inches, number of units sold,
revenue gained, etc.
Corresponds to the JSON property measures
2913 2914 2915 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2913 def measures @measures end |
#time_series_query ⇒ Google::Apis::MonitoringV1::TimeSeriesQuery
TimeSeriesQuery collects the set of supported methods for querying time series
data from the Stackdriver metrics API.
Corresponds to the JSON property timeSeriesQuery
2919 2920 2921 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2919 def time_series_query @time_series_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2926 2927 2928 2929 2930 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2926 def update!(**args) @breakdowns = args[:breakdowns] if args.key?(:breakdowns) @measures = args[:measures] if args.key?(:measures) @time_series_query = args[:time_series_query] if args.key?(:time_series_query) end |