Class: Google::Apis::MonitoringV1::Widget
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV1::Widget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb
Overview
Widget contains a single dashboard component and configuration of how to present the component in the dashboard.
Instance Attribute Summary collapse
-
#alert_chart ⇒ Google::Apis::MonitoringV1::AlertChart
A chart that displays alert policy data.
-
#blank ⇒ Google::Apis::MonitoringV1::Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
-
#collapsible_group ⇒ Google::Apis::MonitoringV1::CollapsibleGroup
A widget that groups the other widgets.
-
#error_reporting_panel ⇒ Google::Apis::MonitoringV1::ErrorReportingPanel
A widget that displays a list of error groups.
-
#filter_control ⇒ Google::Apis::MonitoringV1::FilterControl
A widget that displays an input field to change the value of a template variable.
-
#id ⇒ String
Optional.
-
#incident_list ⇒ Google::Apis::MonitoringV1::IncidentList
A widget that displays a list of incidents Corresponds to the JSON property
incidentList. -
#logs_panel ⇒ Google::Apis::MonitoringV1::LogsPanel
A widget that displays a stream of log.
-
#pie_chart ⇒ Google::Apis::MonitoringV1::PieChart
A widget that displays timeseries data as a pie or a donut.
-
#scorecard ⇒ Google::Apis::MonitoringV1::Scorecard
A widget showing the latest value of a metric, and how this value relates to one or more thresholds.
-
#section_header ⇒ Google::Apis::MonitoringV1::SectionHeader
A widget that defines a new section header.
-
#single_view_group ⇒ Google::Apis::MonitoringV1::SingleViewGroup
A widget that groups the other widgets by using a dropdown menu.
-
#text ⇒ Google::Apis::MonitoringV1::Text
A widget that displays textual content.
-
#time_series_table ⇒ Google::Apis::MonitoringV1::TimeSeriesTable
A table that displays time series data.
-
#title ⇒ String
Optional.
-
#treemap ⇒ Google::Apis::MonitoringV1::Treemap
A widget that displays hierarchical data as a treemap.
-
#visibility_condition ⇒ Google::Apis::MonitoringV1::VisibilityCondition
Condition that determines whether the widget should be displayed.
-
#xy_chart ⇒ Google::Apis::MonitoringV1::XyChart
A chart that displays data on a 2D (X and Y axes) plane.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Widget
constructor
A new instance of Widget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Widget
Returns a new instance of Widget.
3094 3095 3096 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alert_chart ⇒ Google::Apis::MonitoringV1::AlertChart
A chart that displays alert policy data.
Corresponds to the JSON property alertChart
2997 2998 2999 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 2997 def alert_chart @alert_chart end |
#blank ⇒ Google::Apis::MonitoringV1::Empty
A generic empty message that you can re-use to avoid defining duplicated empty
messages in your APIs. A typical example is to use it as the request or the
response type of an API method. For instance: service Foo rpc Bar(google.
protobuf.Empty) returns (google.protobuf.Empty);
Corresponds to the JSON property blank
3005 3006 3007 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3005 def blank @blank end |
#collapsible_group ⇒ Google::Apis::MonitoringV1::CollapsibleGroup
A widget that groups the other widgets. All widgets that are within the area
spanned by the grouping widget are considered member widgets.
Corresponds to the JSON property collapsibleGroup
3011 3012 3013 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3011 def collapsible_group @collapsible_group end |
#error_reporting_panel ⇒ Google::Apis::MonitoringV1::ErrorReportingPanel
A widget that displays a list of error groups.
Corresponds to the JSON property errorReportingPanel
3016 3017 3018 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3016 def error_reporting_panel @error_reporting_panel end |
#filter_control ⇒ Google::Apis::MonitoringV1::FilterControl
A widget that displays an input field to change the value of a template
variable.
Corresponds to the JSON property filterControl
3022 3023 3024 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3022 def filter_control @filter_control end |
#id ⇒ String
Optional. The widget id. Ids may be made up of alphanumerics, dashes and
underscores. Widget ids are optional.
Corresponds to the JSON property id
3028 3029 3030 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3028 def id @id end |
#incident_list ⇒ Google::Apis::MonitoringV1::IncidentList
A widget that displays a list of incidents
Corresponds to the JSON property incidentList
3033 3034 3035 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3033 def incident_list @incident_list end |
#logs_panel ⇒ Google::Apis::MonitoringV1::LogsPanel
A widget that displays a stream of log.
Corresponds to the JSON property logsPanel
3038 3039 3040 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3038 def logs_panel @logs_panel end |
#pie_chart ⇒ Google::Apis::MonitoringV1::PieChart
A widget that displays timeseries data as a pie or a donut.
Corresponds to the JSON property pieChart
3043 3044 3045 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3043 def pie_chart @pie_chart end |
#scorecard ⇒ Google::Apis::MonitoringV1::Scorecard
A widget showing the latest value of a metric, and how this value relates to
one or more thresholds.
Corresponds to the JSON property scorecard
3049 3050 3051 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3049 def scorecard @scorecard end |
#section_header ⇒ Google::Apis::MonitoringV1::SectionHeader
A widget that defines a new section header. Sections populate a table of
contents and allow easier navigation of long-form content.
Corresponds to the JSON property sectionHeader
3055 3056 3057 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3055 def section_header @section_header end |
#single_view_group ⇒ Google::Apis::MonitoringV1::SingleViewGroup
A widget that groups the other widgets by using a dropdown menu. All widgets
that are within the area spanned by the grouping widget are considered member
widgets.
Corresponds to the JSON property singleViewGroup
3062 3063 3064 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3062 def single_view_group @single_view_group end |
#text ⇒ Google::Apis::MonitoringV1::Text
A widget that displays textual content.
Corresponds to the JSON property text
3067 3068 3069 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3067 def text @text end |
#time_series_table ⇒ Google::Apis::MonitoringV1::TimeSeriesTable
A table that displays time series data.
Corresponds to the JSON property timeSeriesTable
3072 3073 3074 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3072 def time_series_table @time_series_table end |
#title ⇒ String
Optional. The title of the widget.
Corresponds to the JSON property title
3077 3078 3079 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3077 def title @title end |
#treemap ⇒ Google::Apis::MonitoringV1::Treemap
A widget that displays hierarchical data as a treemap.
Corresponds to the JSON property treemap
3082 3083 3084 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3082 def treemap @treemap end |
#visibility_condition ⇒ Google::Apis::MonitoringV1::VisibilityCondition
Condition that determines whether the widget should be displayed.
Corresponds to the JSON property visibilityCondition
3087 3088 3089 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3087 def visibility_condition @visibility_condition end |
#xy_chart ⇒ Google::Apis::MonitoringV1::XyChart
A chart that displays data on a 2D (X and Y axes) plane.
Corresponds to the JSON property xyChart
3092 3093 3094 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3092 def xy_chart @xy_chart end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 3117 3118 |
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3099 def update!(**args) @alert_chart = args[:alert_chart] if args.key?(:alert_chart) @blank = args[:blank] if args.key?(:blank) @collapsible_group = args[:collapsible_group] if args.key?(:collapsible_group) @error_reporting_panel = args[:error_reporting_panel] if args.key?(:error_reporting_panel) @filter_control = args[:filter_control] if args.key?(:filter_control) @id = args[:id] if args.key?(:id) @incident_list = args[:incident_list] if args.key?(:incident_list) @logs_panel = args[:logs_panel] if args.key?(:logs_panel) @pie_chart = args[:pie_chart] if args.key?(:pie_chart) @scorecard = args[:scorecard] if args.key?(:scorecard) @section_header = args[:section_header] if args.key?(:section_header) @single_view_group = args[:single_view_group] if args.key?(:single_view_group) @text = args[:text] if args.key?(:text) @time_series_table = args[:time_series_table] if args.key?(:time_series_table) @title = args[:title] if args.key?(:title) @treemap = args[:treemap] if args.key?(:treemap) @visibility_condition = args[:visibility_condition] if args.key?(:visibility_condition) @xy_chart = args[:xy_chart] if args.key?(:xy_chart) end |