Class: Google::Apis::MonitoringV1::Widget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v1/classes.rb,
lib/google/apis/monitoring_v1/representations.rb,
lib/google/apis/monitoring_v1/representations.rb

Overview

Widget contains a single dashboard component and configuration of how to present the component in the dashboard.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Widget

Returns a new instance of Widget.



3124
3125
3126
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_chartGoogle::Apis::MonitoringV1::AlertChart

A chart that displays alert policy data. Corresponds to the JSON property alertChart



3020
3021
3022
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3020

def alert_chart
  @alert_chart
end

#blankGoogle::Apis::MonitoringV1::Empty

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty); Corresponds to the JSON property blank



3028
3029
3030
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3028

def blank
  @blank
end

#collapsible_groupGoogle::Apis::MonitoringV1::CollapsibleGroup

A widget that groups the other widgets. All widgets that are within the area spanned by the grouping widget are considered member widgets. Corresponds to the JSON property collapsibleGroup



3034
3035
3036
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3034

def collapsible_group
  @collapsible_group
end

#coordinated_widgetGoogle::Apis::MonitoringV1::CoordinatedWidget

A widget that contains two widget visualizations that are coordinated in display. Currently, we only support the primary widget of TimeSeriesTable with the secondary widget of XyChart. Corresponds to the JSON property coordinatedWidget



3041
3042
3043
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3041

def coordinated_widget
  @coordinated_widget
end

#error_reporting_panelGoogle::Apis::MonitoringV1::ErrorReportingPanel

A widget that displays a list of error groups. Corresponds to the JSON property errorReportingPanel



3046
3047
3048
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3046

def error_reporting_panel
  @error_reporting_panel
end

#filter_controlGoogle::Apis::MonitoringV1::FilterControl

A widget that displays an input field to change the value of a template variable. Corresponds to the JSON property filterControl



3052
3053
3054
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3052

def filter_control
  @filter_control
end

#idString

Optional. The widget id. Ids may be made up of alphanumerics, dashes and underscores. Widget ids are optional. Corresponds to the JSON property id

Returns:

  • (String)


3058
3059
3060
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3058

def id
  @id
end

#incident_listGoogle::Apis::MonitoringV1::IncidentList

A widget that displays a list of incidents Corresponds to the JSON property incidentList



3063
3064
3065
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3063

def incident_list
  @incident_list
end

#logs_panelGoogle::Apis::MonitoringV1::LogsPanel

A widget that displays a stream of log. Corresponds to the JSON property logsPanel



3068
3069
3070
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3068

def logs_panel
  @logs_panel
end

#pie_chartGoogle::Apis::MonitoringV1::PieChart

A widget that displays timeseries data as a pie or a donut. Corresponds to the JSON property pieChart



3073
3074
3075
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3073

def pie_chart
  @pie_chart
end

#scorecardGoogle::Apis::MonitoringV1::Scorecard

A widget showing the latest value of a metric, and how this value relates to one or more thresholds. Corresponds to the JSON property scorecard



3079
3080
3081
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3079

def scorecard
  @scorecard
end

#section_headerGoogle::Apis::MonitoringV1::SectionHeader

A widget that defines a new section header. Sections populate a table of contents and allow easier navigation of long-form content. Corresponds to the JSON property sectionHeader



3085
3086
3087
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3085

def section_header
  @section_header
end

#single_view_groupGoogle::Apis::MonitoringV1::SingleViewGroup

A widget that groups the other widgets by using a dropdown menu. All widgets that are within the area spanned by the grouping widget are considered member widgets. Corresponds to the JSON property singleViewGroup



3092
3093
3094
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3092

def single_view_group
  @single_view_group
end

#textGoogle::Apis::MonitoringV1::Text

A widget that displays textual content. Corresponds to the JSON property text



3097
3098
3099
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3097

def text
  @text
end

#time_series_tableGoogle::Apis::MonitoringV1::TimeSeriesTable

A table that displays time series data. Corresponds to the JSON property timeSeriesTable



3102
3103
3104
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3102

def time_series_table
  @time_series_table
end

#titleString

Optional. The title of the widget. Corresponds to the JSON property title

Returns:

  • (String)


3107
3108
3109
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3107

def title
  @title
end

#treemapGoogle::Apis::MonitoringV1::Treemap

A widget that displays hierarchical data as a treemap. Corresponds to the JSON property treemap



3112
3113
3114
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3112

def treemap
  @treemap
end

#visibility_conditionGoogle::Apis::MonitoringV1::VisibilityCondition

Condition that determines whether the widget should be displayed. Corresponds to the JSON property visibilityCondition



3117
3118
3119
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3117

def visibility_condition
  @visibility_condition
end

#xy_chartGoogle::Apis::MonitoringV1::XyChart

A chart that displays data on a 2D (X and Y axes) plane. Corresponds to the JSON property xyChart



3122
3123
3124
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3122

def xy_chart
  @xy_chart
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
3147
3148
3149
# File 'lib/google/apis/monitoring_v1/classes.rb', line 3129

def update!(**args)
  @alert_chart = args[:alert_chart] if args.key?(:alert_chart)
  @blank = args[:blank] if args.key?(:blank)
  @collapsible_group = args[:collapsible_group] if args.key?(:collapsible_group)
  @coordinated_widget = args[:coordinated_widget] if args.key?(:coordinated_widget)
  @error_reporting_panel = args[:error_reporting_panel] if args.key?(:error_reporting_panel)
  @filter_control = args[:filter_control] if args.key?(:filter_control)
  @id = args[:id] if args.key?(:id)
  @incident_list = args[:incident_list] if args.key?(:incident_list)
  @logs_panel = args[:logs_panel] if args.key?(:logs_panel)
  @pie_chart = args[:pie_chart] if args.key?(:pie_chart)
  @scorecard = args[:scorecard] if args.key?(:scorecard)
  @section_header = args[:section_header] if args.key?(:section_header)
  @single_view_group = args[:single_view_group] if args.key?(:single_view_group)
  @text = args[:text] if args.key?(:text)
  @time_series_table = args[:time_series_table] if args.key?(:time_series_table)
  @title = args[:title] if args.key?(:title)
  @treemap = args[:treemap] if args.key?(:treemap)
  @visibility_condition = args[:visibility_condition] if args.key?(:visibility_condition)
  @xy_chart = args[:xy_chart] if args.key?(:xy_chart)
end